@@ -164,7 +164,7 @@ class CarModel:
         self.set_hot_emissions()
         self.set_noise_emissions()
         self.create_PHEV()
-        if drop_hybrids==True:
+        if drop_hybrids:
             self.drop_hybrid()
 
     def adjust_cost(self):
@@ -910,11 +910,36 @@ class CarModel:
             "Ammonia direct emissions, urban",
             "Lead direct emissions, urban",
             "Benzene direct emissions, urban",
+            "Ethane direct emissions, urban",
+            "Propane direct emissions, urban",
+            "Butane direct emissions, urban",
+            "Pentane direct emissions, urban",
+            "Hexane direct emissions, urban",
+            "Cyclohexane direct emissions, urban",
+            "Heptane direct emissions, urban",
+            "Ethene direct emissions, urban",
+            "Propene direct emissions, urban",
+            "1-Pentene direct emissions, urban",
             "Toluene direct emissions, urban",
-            "Xylene direct emissions, urban",
+            "m-Xylene direct emissions, urban",
+            "o-Xylene direct emissions, urban",
             "Formaldehyde direct emissions, urban",
             "Acetaldehyde direct emissions, urban",
-
+            "Benzaldehyde direct emissions, urban",
+            "Acetone direct emissions, urban",
+            "Methyl ethyl ketone direct emissions, urban",
+            "Acrolein direct emissions, urban",
+            "Styrene direct emissions, urban",
+            'PAH, polycyclic aromatic hydrocarbons direct emissions, urban',
+            'Arsenic direct emissions, urban',
+            'Selenium direct emissions, urban',
+            'Zinc direct emissions, urban',
+            'Copper direct emissions, urban',
+            'Nickel direct emissions, urban',
+            'Chromium direct emissions, urban',
+            'Chromium VI direct emissions, urban',
+            'Mercury direct emissions, urban',
+            'Cadmium direct emissions, urban',
             "Hydrocarbons direct emissions, suburban",
             "Carbon monoxide direct emissions, suburban",
             "Nitrogen oxides direct emissions, suburban",
@@ -925,11 +950,36 @@ class CarModel:
             "Ammonia direct emissions, suburban",
             "Lead direct emissions, suburban",
             "Benzene direct emissions, suburban",
+            "Ethane direct emissions, suburban",
+            "Propane direct emissions, suburban",
+            "Butane direct emissions, suburban",
+            "Pentane direct emissions, suburban",
+            "Hexane direct emissions, suburban",
+            "Cyclohexane direct emissions, suburban",
+            "Heptane direct emissions, suburban",
+            "Ethene direct emissions, suburban",
+            "Propene direct emissions, suburban",
+            "1-Pentene direct emissions, suburban",
             "Toluene direct emissions, suburban",
-            "Xylene direct emissions, suburban",
+            "m-Xylene direct emissions, suburban",
+            "o-Xylene direct emissions, suburban",
             "Formaldehyde direct emissions, suburban",
             "Acetaldehyde direct emissions, suburban",
-
+            "Benzaldehyde direct emissions, suburban",
+            "Acetone direct emissions, suburban",
+            "Methyl ethyl ketone direct emissions, suburban",
+            "Acrolein direct emissions, suburban",
+            "Styrene direct emissions, suburban",
+            'PAH, polycyclic aromatic hydrocarbons direct emissions, suburban',
+            'Arsenic direct emissions, suburban',
+            'Selenium direct emissions, suburban',
+            'Zinc direct emissions, suburban',
+            'Copper direct emissions, suburban',
+            'Nickel direct emissions, suburban',
+            'Chromium direct emissions, suburban',
+            'Chromium VI direct emissions, suburban',
+            'Mercury direct emissions, suburban',
+            'Cadmium direct emissions, suburban',
             "Hydrocarbons direct emissions, rural",
             "Carbon monoxide direct emissions, rural",
             "Nitrogen oxides direct emissions, rural",
@@ -940,11 +990,36 @@ class CarModel:
             "Ammonia direct emissions, rural",
             "Lead direct emissions, rural",
             "Benzene direct emissions, rural",
+            "Ethane direct emissions, rural",
+            "Propane direct emissions, rural",
+            "Butane direct emissions, rural",
+            "Pentane direct emissions, rural",
+            "Hexane direct emissions, rural",
+            "Cyclohexane direct emissions, rural",
+            "Heptane direct emissions, rural",
+            "Ethene direct emissions, rural",
+            "Propene direct emissions, rural",
+            "1-Pentene direct emissions, rural",
             "Toluene direct emissions, rural",
-            "Xylene direct emissions, rural",
+            "m-Xylene direct emissions, rural",
+            "o-Xylene direct emissions, rural",
             "Formaldehyde direct emissions, rural",
             "Acetaldehyde direct emissions, rural",
-
+            "Benzaldehyde direct emissions, rural",
+            "Acetone direct emissions, rural",
+            "Methyl ethyl ketone direct emissions, rural",
+            "Acrolein direct emissions, rural",
+            "Styrene direct emissions, rural",
+            'PAH, polycyclic aromatic hydrocarbons direct emissions, rural',
+            'Arsenic direct emissions, rural',
+            'Selenium direct emissions, rural',
+            'Zinc direct emissions, rural',
+            'Copper direct emissions, rural',
+            'Nickel direct emissions, rural',
+            'Chromium direct emissions, rural',
+            'Chromium VI direct emissions, rural',
+            'Mercury direct emissions, rural',
+            'Cadmium direct emissions, rural',
         ]
 
         l_y = []
@@ -1078,11 +1153,9 @@ class CarModel:
         """
 
         if scope is None:
-            scope = {}
-            scope["size"] = self.array.coords["size"].values.tolist()
-            scope["powertrain"] = self.array.coords["powertrain"].values.tolist()
-            scope["year"] = self.array.coords["year"].values.tolist()
-
+            scope = {"size": self.array.coords["size"].values.tolist(),
+                     "powertrain": self.array.coords["powertrain"].values.tolist(),
+                     "year": self.array.coords["year"].values.tolist()}
 
         list_cost_cat = ["purchase", "maintenance", "component replacement", "energy", "total"]
 
